@@ -2,13 +2,14 @@ require 'aruba/cucumber'
 require 'fileutils'
 
 module ArubaExt
-  def run_command(cmd, timeout = nil)
+  def run_command_and_stop(cmd, opts = {})
     exec_cmd = cmd =~ /^rspec/ ? "bin/#{cmd}" : cmd
+
     unset_bundler_env_vars
     # Ensure the correct Gemfile and binstubs are found
     in_current_directory do
       with_unbundled_env do
-        super(exec_cmd, timeout)
+        super(exec_cmd, opts)
       end
     end
   end
@@ -59,7 +60,7 @@ Before do
   # We want fresh `example_app` project with empty `spec` dir except helpers.
   # FileUtils.cp_r on Ruby 1.9.2 doesn't preserve permissions.
   system('cp', '-r', example_app_dir, aruba_dir)
-  helpers = %w[spec/spec_helper.rb spec/rails_helper.rb spec/support/capybara.rb]
+  helpers = %w[spec/spec_helper.rb spec/rails_helper.rb]
   directories = []
 
   Dir["#{aruba_dir}/spec/**/*"].each do |path|
