@@ -7,6 +7,12 @@ RSpec.describe Rspec::Generators::ScaffoldGenerator, type: :generator do
   include RSpec::Support::InSubProcess
   setup_default_destination
 
+  if Rack::RELEASE < "3.1.0"
+    let(:unprocessable_status) { ":unprocessable_entity" }
+  else
+    let(:unprocessable_status) { ":unprocessable_content" }
+  end
+
   describe 'standard request specs' do
     subject(:filename) { file('spec/requests/posts_spec.rb') }
 
@@ -32,6 +38,8 @@ RSpec.describe Rspec::Generators::ScaffoldGenerator, type: :generator do
           contain(/renders a response with 422 status \(i.e. to display the 'new' template\)/)
             .and(contain(/renders a response with 422 status \(i.e. to display the 'edit' template\)/))
         )
+
+        expect(filename).to contain(/expect\(response\).to have_http_status\(#{unprocessable_status}\)/)
       end
     end
 
@@ -99,6 +107,7 @@ RSpec.describe Rspec::Generators::ScaffoldGenerator, type: :generator do
         expect(filename).to contain(/renders a response with 422 status \(i.e. to display the 'new' template\)/)
                               .and(contain(/renders a response with 422 status \(i.e. to display the 'edit' template\)/))
 
+        expect(filename).to contain(/expect\(response\).to have_http_status\(#{unprocessable_status}\)/)
         expect(filename).not_to contain(/"renders a JSON response with the new \w+"/)
         expect(filename).not_to contain(/"renders a JSON response with errors for the new \w+"/)
         expect(filename).not_to contain(/"renders a JSON response with the \w+"/)
