@@ -10,7 +10,7 @@ RSpec.describe Rspec::Generators::ViewGenerator, type: :generator do
       run_generator %w[posts index]
       file('spec/views/posts/index.html.erb_spec.rb').tap do |f|
         expect(f).to contain(/require 'rails_helper'/)
-        expect(f).to contain(/^RSpec.describe \"posts\/index\", #{type_metatag(:view)}/)
+        expect(f).to contain(/^RSpec.describe "posts\/index", #{type_metatag(:view)}/)
       end
     end
 
@@ -19,7 +19,7 @@ RSpec.describe Rspec::Generators::ViewGenerator, type: :generator do
         run_generator %w[admin/posts index]
         file('spec/views/admin/posts/index.html.erb_spec.rb').tap do |f|
           expect(f).to contain(/require 'rails_helper'/)
-          expect(f).to contain(/^RSpec.describe \"admin\/posts\/index\", #{type_metatag(:view)}/)
+          expect(f).to contain(/^RSpec.describe "admin\/posts\/index", #{type_metatag(:view)}/)
         end
       end
     end
@@ -30,7 +30,7 @@ RSpec.describe Rspec::Generators::ViewGenerator, type: :generator do
       run_generator %w[posts index --template_engine haml]
       file('spec/views/posts/index.html.haml_spec.rb').tap do |f|
         expect(f).to contain(/require 'rails_helper'/)
-        expect(f).to contain(/^RSpec.describe \"posts\/index\", #{type_metatag(:view)}/)
+        expect(f).to contain(/^RSpec.describe "posts\/index", #{type_metatag(:view)}/)
       end
     end
   end
