@@ -1,6 +1,4 @@
-require "spec_helper"
-
-describe RSpec::Rails::AssertionDelegator do
+RSpec.describe RSpec::Rails::AssertionDelegator do
   it "provides a module that delegates assertion methods to an isolated class" do
     klass = Class.new {
       include RSpec::Rails::AssertionDelegator.new(RSpec::Rails::Assertions)
@@ -12,7 +10,7 @@ describe RSpec::Rails::AssertionDelegator do
   it "delegates back to the including instance for methods the assertion module requires" do
     assertions = Module.new {
       def has_thing?(thing)
-        self.things.include?(thing)
+        things.include?(thing)
       end
     }
 
