@@ -78,7 +78,7 @@ RSpec.describe "Configuration" do
 
     include_examples "adds setting", :global_fixtures
 
-    include_examples "adds setting", :fixture_path
+    include_examples "adds setting", :fixture_paths
 
     include_examples "adds setting", :rendering_views
 
@@ -93,7 +93,7 @@ RSpec.describe "Configuration" do
     end
 
     describe "`#render_views=`" do
-      it "sets `render_views?` to the truthyness of the provided value" do
+      it "sets `render_views?` to the truthiness of the provided value" do
         expect {
           config.render_views = :a_value
         }.to change { config.render_views? }.from(false).to(true)
@@ -158,19 +158,31 @@ RSpec.describe "Configuration" do
   end
 
   it "fixture support is included with metadata `:use_fixtures`" do
+    RSpec.configuration.global_fixtures = [:foo]
+    RSpec.configuration.fixture_paths = ["custom/path"]
+
+    group = RSpec.describe("Arbitrary Description", :use_fixtures)
+
+    expect(group.fixture_paths).to eq(["custom/path"])
+
+    expect(group.new.respond_to?(:foo, true)).to be(true)
+  end
+
+  it "fixture support is included with metadata `:use_fixtures` and fixture_paths configured" do
     in_sub_process do
       RSpec.configuration.global_fixtures = [:foo]
-      RSpec.configuration.fixture_path = "custom/path"
+      RSpec.configuration.fixture_paths = ["custom/path", "other/custom/path"]
 
       group = RSpec.describe("Arbitrary Description", :use_fixtures)
 
-      expect(group).to respond_to(:fixture_path)
-      expect(group.fixture_path).to eq("custom/path")
+      expect(group).to respond_to(:fixture_paths)
+      expect(group.fixture_paths).to eq(["custom/path", "other/custom/path"])
+
       expect(group.new.respond_to?(:foo, true)).to be(true)
     end
   end
 
-  it "metadata `:type => :controller` sets up controller example groups" do
+  it "metadata `type: :controller` sets up controller example groups" do
     a_controller_class = Class.new
     stub_const "SomeController", a_controller_class
 
