@@ -1,11 +1,9 @@
-require 'spec_helper'
-
 class CollectionOwner < ActiveRecord::Base
   connection.execute <<-SQL
     CREATE TABLE collection_owners (
       id integer PRIMARY KEY AUTOINCREMENT
     )
-SQL
+  SQL
   has_many :associated_items do
     def has_some_quality?; true end
   end
@@ -17,11 +15,11 @@ class AssociatedItem < ActiveRecord::Base
       id integer PRIMARY KEY AUTOINCREMENT,
       collection_owner_id integer
     )
-SQL
+  SQL
   belongs_to :collection_owner
 end
 
-describe "should have_xxx" do
+RSpec.describe "should have_xxx" do
   it "works with ActiveRecord::Associations::CollectionProxy" do
     owner = CollectionOwner.new
     expect(owner.associated_items).to have_some_quality
